package be.ac.ulb.code.wit.contacts;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

@XmlRootElement(name="Group", namespace="")
public class ContactGroup {
    @XmlElement(required=true)
	public String name;

    @XmlTransient
	public List<Contact> contacts;

	public ContactGroup() { }

	public ContactGroup(String name) {
		this.name = name;
        this.contacts = new ArrayList<Contact>();
	}

	public void addContact(Contact contact) {
		if (!contacts.contains(contact)) this.contacts.add(contact);
		if (!contact.groups.contains(this)) contact.groups.add(this);
	}

	public void removeContact(Contact contact) {
		if (contacts.contains(contact)) this.contacts.remove(contact);
		if (contact.groups.contains(this)) contact.groups.remove(this);
	}

    // The following emulates the database

    private static HashMap<String, ContactGroup> groups = new HashMap<String,ContactGroup>();
    private boolean saved = false;

    public void save() {
        if (!saved) {
            saved = true;
            groups.put(this.name, this);

            for(Contact contact: this.contacts) {
                contact.save();
            }

            saved = false;
        }
    }

    public void remove() {
        groups.remove(this.name);

        for (Contact c: this.contacts) {
            c.groups.remove(this);
        }
    }

    public static Collection<ContactGroup> FindAll() {
        return groups.values();
    }

    public static ContactGroup FindByName(String name) {
        return groups.get(name);
    }
}
