package be.ac.ulb.code.wit;

import org.apache.cxf.frontend.ServerFactoryBean;

import be.ac.ulb.code.wit.contacts.Contact;
import be.ac.ulb.code.wit.contacts.ContactGroup;
import be.ac.ulb.code.wit.service.ContactService;
import be.ac.ulb.code.wit.service.ContactServiceImpl;
import be.ac.ulb.code.wit.service.GroupService;
import be.ac.ulb.code.wit.service.GroupServiceImpl;

public class ServiceServer {
    public static String contacts_address = "http://localhost:8080/contacts";
    public static String groups_address = "http://localhost:8080/groups";

	private static void cleanup() {
		for (ContactGroup c: ContactGroup.FindAll()) {
			c.remove();
		}

		for (Contact c: Contact.FindAll()) {
			c.remove();
		}
	}

    private static void setupDatabase() {
    	cleanup();
    	
		ContactGroup enterprise = new ContactGroup("USS Enterprise");
		ContactGroup excelsior = new ContactGroup("USS Excelsior");
		ContactGroup starfleet = new ContactGroup("Starfleet");
		ContactGroup klingons = new ContactGroup("Klingon Empire");

		Contact jamesTKirk = new Contact("james.t.kirk@starfleet.gxy");
		Contact spock = new Contact("spock@starfleet.gxy");
		Contact bones = new Contact("leonard.mccoy@starfleet.gxy");
		Contact sulu = new Contact("hikaru.sulu@starfleet.gxy");
		Contact kahless = new Contact("kahless-the-unforgettable@klingon-empire.gxy");
		Contact korax = new Contact("korax@iks.gro-th.gxy");

		enterprise.addContact(jamesTKirk);
		enterprise.addContact(spock);
		enterprise.addContact(bones);
		enterprise.save();

		excelsior.addContact(sulu);
		excelsior.save();

		klingons.addContact(korax);
		klingons.addContact(kahless);
		klingons.save();

		starfleet.addContact(sulu);
		starfleet.addContact(bones);
		starfleet.addContact(spock);
		starfleet.addContact(jamesTKirk);
		starfleet.save();
    }
    
    private <T> void createService(Class<T> clazz, T implementation, String address) {
        ServerFactoryBean factory = new ServerFactoryBean();
	    factory.setAddress(address);
	    factory.setServiceClass(clazz);
	    factory.setServiceBean(implementation);
        factory.create();
        
        System.out.println(String.format("Service for %s available at %s", clazz.toString(), address));
    }

	public ServiceServer() {
        setupDatabase();
        
        createService(ContactService.class, new ContactServiceImpl(), contacts_address);
        createService(GroupService.class, new GroupServiceImpl(), groups_address);
    }

    public static void main(String args[]) throws Exception {
        System.out.println("Starting Server");
        new ServiceServer();
		System.in.read();
    }
}
