package be.ac.ulb.code.wit.contacts;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name="Contact", namespace="")
public class Contact {
    @XmlElement(required=true)
	public String email;

    @XmlElement(required=true)
	public Collection<ContactGroup> groups;

	public Contact() { this.groups = new ArrayList<ContactGroup>(); }

	public Contact(String email) {
		this.email = email;
        this.groups = new ArrayList<ContactGroup>();
	}

    public String toString() {
        String result = email + " (";
        boolean first = true;

        for (ContactGroup g: groups) {
            result += (first ? "" : ", ") + g.name;
            first = false;
        }

        result += ")";
        return result;
    }

    // The following emulates the database

    private static HashMap<String, Contact> contacts = new HashMap<String,Contact>();
    private boolean saved = false;

    public void save() {
        if (!saved) {
            saved = true;
            contacts.put(this.email, this);

            for(ContactGroup group: this.groups) {
                group.save();
            }

            saved = false;
        }
    }

    public void remove() {
        for(ContactGroup group: this.groups) {
            group.contacts.remove(this);
        }

        contacts.remove(this.email);
    }

    public static Contact FindByEmail(String email) {
        return contacts.get(email);
    }

    public static Collection<Contact> FindAll() {
        return contacts.values();
    }
}
