package be.ac.ulb.code.wit.service;

import javax.jws.WebService;
import be.ac.ulb.code.wit.contacts.*;

@WebService
public interface GroupService {
	/**
	 * Retrieves all contacts in the specified group.
	 * @param group The group for which contacts are to be retrieved
	 * @return the list of all contacts belonging to the specified group
	 * @throws NoSuchGroupException when the specified group cannot be found.
	 */
	public abstract Contact[] getGroupContacts(String group) throws NoSuchGroupException;

	/**
	 * Add a contact to a group.
	 * @param contact The contact to be added to the group
	 * @param group The group to which the contact is to be added.
	 * @throws NoSuchGroupException when the specified group cannot be found.
	 * @throws NoSuchContactException when the specified contact cannot be found.
	 */
	public abstract void addContactToGroup(Contact contact, String group)
			throws NoSuchContactException, NoSuchGroupException;

	/**
	 * Remove a contact from a group.
	 * @param email The contact to be removed from the group
	 * @param group The group from which the contact is to be removed.
	 * @throws NoSuchGroupException when the specified group cannot be found.
	 * @throws NoSuchContactException when the specified contact cannot be found.
	 */
	public abstract void removeContactFromGroup(Contact contact, String group)
			throws NoSuchContactException, NoSuchGroupException;


}
